When the returned content by the SHERPA/RoMEO API is a list of publishers this function parses the list and returns a structured data.frame with the default policies of the different publisher.
parse_publisher(xml_source, outcome, hits)xml API answer
Returns a data frame with the following columns:
romeoid [integer(1)]
the internal index of the publisher in the SHERPA/RoMEO
database
publisher [character(1)]
the name of the publisher
alias [character(1)]
if applicable an alternative name of the publisher or the
name of the specific publishing branch
romeocolour [character(1)]
a colour assigned by the database that reflects the default
policies of the publisher
preprint [character(1)]
is the preprint (not reviewed) archivable?
postprint [character(1)]
is the postprint (reviewed but not formatted) archivable?
pdf [character(1)]
is the publisher's version (reviewed and formatted)
archivable?